QT_TRANSLATE_NOOP("InstrumentsXML", "Common"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Pop/Rock"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Jazz"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Choral"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Orchestra"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Concert Band"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Marching Band"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Electronic Music"),
QT_TRANSLATE_NOOP("InstrumentsXML", "World Music"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Early Music"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Classroom"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Woodwinds"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Winds"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "W.", "Winds"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Piccolo"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Picc.", "Piccolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "D♭ Piccolo"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "D♭ Picc.", "D♭ Piccolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Flute"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Fl.", "Flute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Treble Flute"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Tr. Fl.", "Treble Flute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Flute"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Sop. Fl.", "Soprano Flute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sub Contra-alto Flute"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Sc-a. Fl.", "Sub Contra-alto Flute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Flute"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A. Fl.", "Alto Flute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Flute"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B. Fl.", "Bass Flute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contra-alto Flute"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "C-a. Fl.", "Contra-alto Flute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabass Flute"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Cb. Fl.", "Contrabass Flute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Double Contrabass Flute"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "D. Cb. Fl.", "Double Contrabass Flute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Hyperbass Flute"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Hb. Fl.", "Hyperbass Flute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Traverso"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Trv.", "Traverso"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Danso"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Da.", "Danso"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Dizi"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Di.", "Dizi"),
QT_TRANSLATE_NOOP("InstrumentsXML", "C Dizi"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "C Di.", "C Dizi"),
QT_TRANSLATE_NOOP("InstrumentsXML", "A Dizi"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A Di.", "A Dizi"),
QT_TRANSLATE_NOOP("InstrumentsXML", "G Dizi"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "G Di.", "G Dizi"),
QT_TRANSLATE_NOOP("InstrumentsXML", "F Dizi"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "F Di.", "F Dizi"),
QT_TRANSLATE_NOOP("InstrumentsXML", "E Dizi"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "E Di.", "E Dizi"),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Fife"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B♭ Fife", "B♭ Fife"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Flageolet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Fla.", "Flageolet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "French Flageolet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Fr. Fla.", "French Flageolet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "English Flageolet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Eng. Fla.", "English Flageolet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Irish Flute"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Ir. Fl.", "Irish Flute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Gemshorn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Gh.", "Gemshorn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Gemshorn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "S. Gh.", "Soprano Gemshorn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Gemshorn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A. Gh.", "Alto Gemshorn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Gemshorn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "T. Gh.", "Tenor Gemshorn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Gemshorn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B. Gh.", "Bass Gemshorn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Ocarina"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Oc.", "Ocarina"),
QT_TRANSLATE_NOOP("InstrumentsXML", "G Soprano Ocarina"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "G S. Oc.", "G Soprano Ocarina"),
QT_TRANSLATE_NOOP("InstrumentsXML", "F Soprano Ocarina"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "F S. Oc.", "F Soprano Ocarina"),
QT_TRANSLATE_NOOP("InstrumentsXML", "C Soprano Ocarina"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "C S. Oc.", "C Soprano Ocarina"),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Soprano Ocarina"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B♭­ S. Oc.", "B♭ Soprano Ocarina"),
QT_TRANSLATE_NOOP("InstrumentsXML", "G Alto Ocarina"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "G A. Oc.", "G Alto Ocarina"),
QT_TRANSLATE_NOOP("InstrumentsXML", "F Alto Ocarina"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "F A. Oc.", "F Alto Ocarina"),
QT_TRANSLATE_NOOP("InstrumentsXML", "C Alto Ocarina"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "C A. Oc.", "C Alto Ocarina"),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭­ Alto Ocarina"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B♭­ A. Oc.", "B♭­ Alto Ocarina"),
QT_TRANSLATE_NOOP("InstrumentsXML", "C Bass Ocarina"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "C B. Oc.", "C Bass Ocarina"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Pan Flute"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Pn. Fl.", "Pan Flute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Quena"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Qn.", "Quena"),
QT_TRANSLATE_NOOP("InstrumentsXML", "C Quena"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "C Qn.", "C Quena"),
QT_TRANSLATE_NOOP("InstrumentsXML", "G Quena"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "G Qn.", "G Quena"),
QT_TRANSLATE_NOOP("InstrumentsXML", "F Quena"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "F Qn.", "F Quena"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Quena"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Qn.", "Quena"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Recorder"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Rec.", "Recorder"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Garklein Recorder"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Gk. Rec.", "Garklein Recorder"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sopranino Recorder"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Si. Rec.", "Sopranino Recorder"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Recorder"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "S. Rec.", "Soprano Recorder"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Recorder"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A. Rec.", "Alto Recorder"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Recorder"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "T. Rec.", "Tenor Recorder"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Recorder"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B. Rec.", "Bass Recorder"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Greatbass Recorder"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Gb. Rec.", "Greatbass Recorder"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabass Recorder"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Cb. Rec.", "Contrabass Recorder"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Slide Whistle"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Sl. Wh.", "Slide Whistle"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tin Whistle"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Tin Wh.", "Tin Whistle"),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Tin Whistle"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B♭ Tin Wh.", "B♭ Tin Whistle"),
QT_TRANSLATE_NOOP("InstrumentsXML", "D Tin Whistle"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "D Tin Wh.", "D Tin Whistle"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Piccolo Oboe"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "P. Ob.", "Piccolo Oboe"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Oboe"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Ob.", "Oboe"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baroque Oboe"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bq. Ob.", "Baroque Oboe"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Oboe d'amore"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Ob. d'a.", "Oboe d'amore"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Oboe da caccia"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Ob. d. ca.", "Oboe da caccia"),
QT_TRANSLATE_NOOP("InstrumentsXML", "English Horn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "E. Hn.", "English Horn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baritone Oboe"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bar. Ob.", "Baritone Oboe"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Piccolo Heckelphone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "P. Hph.", "Piccolo Heckelphone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Heckelphone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Hph.", "Heckelphone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lupophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Lph.", "Lupophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Heckelphone-clarinet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Hph.", "Heckelphone-clarinet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sopranino Shawm"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Si. Sh.", "Sopranino Shawm"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Shawm"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "S. Sh.", "Soprano Shawm"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Shawm"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A. Sh.", "Alto Shawm"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Shawm"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "T. Sh.", "Tenor Shawm"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Shawm"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B. Sh.", "Bass Shawm"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Great Bass Shawm"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "G.B. Sh.", "Great Bass Shawm"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Cromorne"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Cr.", "Cromorne"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Crumhorn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Crh.", "Crumhorn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Crumhorn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "S. Crh.", "Soprano Crumhorn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Crumhorn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A. Crh.", "Alto Crumhorn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Crumhorn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "T. Crh.", "Tenor Crumhorn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Crumhorn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B. Crh.", "Bass Crumhorn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Greatbass Crumhorn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Gb. Crh.", "Greatbass Crumhorn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Cornamuse"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Cm.", "Cornamuse"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Cornamuse"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "S. Cm.", "Soprano Cornamuse"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Cornamuse"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A. Cm.", "Alto Cornamuse"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Cornamuse"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "T. Cm.", "Tenor Cornamuse"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Cornamuse"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B. Cm.", "Bass Cornamuse"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Duduk"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Du.", "Duduk"),
QT_TRANSLATE_NOOP("InstrumentsXML", "F Duduk"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "F Du.", "F Duduk"),
QT_TRANSLATE_NOOP("InstrumentsXML", "E Duduk"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "E Du.", "E Duduk"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Duduk"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Du.", "Duduk"),
QT_TRANSLATE_NOOP("InstrumentsXML", "C Duduk"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "C Du.", "C Duduk"),
QT_TRANSLATE_NOOP("InstrumentsXML", "B Duduk"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B Du.", "B Duduk"),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Duduk"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B♭ Du.", "B♭ Duduk"),
QT_TRANSLATE_NOOP("InstrumentsXML", "A Duduk"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A Du.", "A Duduk"),
QT_TRANSLATE_NOOP("InstrumentsXML", "G Duduk"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "G Du.", "G Duduk"),
QT_TRANSLATE_NOOP("InstrumentsXML", "A Bass Duduk"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A B. Du.", "A Bass Duduk"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Kelhorn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "S. Kh.", "Soprano Kelhorn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Kelhorn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A. Kh.", "Alto Kelhorn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Kelhorn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "T. Kh.", "Tenor Kelhorn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Kelhorn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B. Kh.", "Bass Kelhorn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Greatbass Kelhorn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Gb. Kh.", "Greatbass Kelhorn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Rauschpfeife"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Rpf.", "Rauschpfeife"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sopranino Rauschpfeife"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Si. Rpf.", "Sopranino Rauschpfeife"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Rauschpfeife"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "S. Rpf.", "Soprano Rauschpfeife"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Shenai"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "She.", "Shenai"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Clarinet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Cl.", "Clarinet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Piccolo Clarinet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "P. Cl.", "Piccolo Clarinet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Clarinet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "S. Cl.", "Soprano Clarinet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "C Clarinet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "C Cl.", "C Clarinet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "D Clarinet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "D Cl.", "D Clarinet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Clarinet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "E♭ Cl.", "E♭ Clarinet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "G Clarinet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "G Cl.", "G Clarinet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Clarinet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B♭ Cl.", "B♭ Clarinet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "A Clarinet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A Cl.", "A Clarinet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Clarinet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A. Cl.", "Alto Clarinet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Basset Clarinet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Ba. Cl.", "Basset Clarinet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Basset Horn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Ba. Hn.", "Basset Horn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Clarinet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B. Cl.", "Bass Clarinet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Bass Clarinet (Bass Clef)"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B♭ B. Cl.", "B♭ Bass Clarinet (Bass Clef)"),
QT_TRANSLATE_NOOP("InstrumentsXML", "A Bass Clarinet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A B. Cl.", "A Bass Clarinet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "A Bass Clarinet (Bass Clef)"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A B. Cl.", "A Bass Clarinet (Bass Clef)"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contra-alto Clarinet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "C-a. Cl.", "Contra-alto Clarinet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabass Clarinet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Cb. Cl.", "Contrabass Clarinet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Chalumeau"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Cha.", "Chalumeau"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sopranino Chalumeau"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Si. Cha.", "Sopranino Chalumeau"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Chalumeau"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "S. Cha.", "Soprano Chalumeau"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Chalumeau"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A. Cha.", "Alto Chalumeau"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Chalumeau"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "T. Cha.", "Tenor Chalumeau"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Chalumeau"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B. Cha.", "Bass Chalumeau"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tarogato"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Tar.", "Tarogato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Octavin"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Oct.", "Octavin"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bassoon"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bsn.", "Bassoon"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabassoon"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Cbsn.", "Contrabassoon"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Reed Contrabass"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Rd. Cbs.", "Reed Contrabass"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Dulcian"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Du.", "Dulcian"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Rackett"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Ra.", "Rackett"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sarrusophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Sar.", "Sarrusophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sopranino Sarrusophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Si. Sar.", "Sopranino Sarrusophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Sarrusophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "S. Sar.", "Soprano Sarrusophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Sarrusophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A. Sar.", "Alto Sarrusophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Sarrusophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "T. Sar.", "Tenor Sarrusophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baritone Sarrusophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bar. Sar.", "Baritone Sarrusophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Sarrusophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B. Sar.", "Bass Sarrusophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabass Sarrusophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Cb. Sar.", "Contrabass Sarrusophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Saxophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Sax.", "Saxophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sopranissimo Saxophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Sio. Sax.", "Sopranissimo Saxophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sopranino Saxophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Si. Sax.", "Sopranino Saxophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Saxophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "S. Sax.", "Soprano Saxophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Aulochrome"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Aul.", "Aulochrome"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Mezzo-Soprano Saxophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "M.S. Sax.", "Mezzo-Soprano Saxophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Saxophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A. Sax.", "Alto Saxophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Melody Saxophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Mel. Sax.", "Melody Saxophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Saxophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "T. Sax.", "Tenor Saxophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baritone Saxophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bar. Sax.", "Baritone Saxophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Saxophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B. Sax.", "Bass Saxophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabass Saxophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Cb. Sax.", "Contrabass Saxophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Subcontrabass Saxophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Scb. Sax.", "Subcontrabass Saxophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bagpipe"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bagp.", "Bagpipe"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Free Reed"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Harmonica"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Harm.", "Harmonica"),
QT_TRANSLATE_NOOP("InstrumentsXML", "12 Hole C Chromatic Harmonica"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Harm.", "12 Hole C Chromatic Harmonica"),
QT_TRANSLATE_NOOP("InstrumentsXML", "14 Hole C Chromatic Harmonica"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Harm.", "14 Hole C Chromatic Harmonica"),
QT_TRANSLATE_NOOP("InstrumentsXML", "12 Hole G Chromatic Harmonica"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Harm.", "12 Hole G Chromatic Harmonica"),
QT_TRANSLATE_NOOP("InstrumentsXML", "16 Hole C Chromatic Harmonica"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Harm.", "16 Hole C Chromatic Harmonica"),
QT_TRANSLATE_NOOP("InstrumentsXML", "12 Hole Tenor C Chromatic Harmonica"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Harm.", "12 Hole Tenor C Chromatic Harmonica"),
QT_TRANSLATE_NOOP("InstrumentsXML", "10 Hole High G Diatonic Harmonica"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Harm.", "10 Hole High G Diatonic Harmonica"),
QT_TRANSLATE_NOOP("InstrumentsXML", "10 Hole F Diatonic Harmonica"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Harm.", "10 Hole F Diatonic Harmonica"),
QT_TRANSLATE_NOOP("InstrumentsXML", "10 Hole D Diatonic Harmonica"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Harm.", "10 Hole D Diatonic Harmonica"),
QT_TRANSLATE_NOOP("InstrumentsXML", "10 Hole C Diatonic Harmonica"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Harm.", "10 Hole C Diatonic Harmonica"),
QT_TRANSLATE_NOOP("InstrumentsXML", "10 Hole A Diatonic Harmonica"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Harm.", "10 Hole A Diatonic Harmonica"),
QT_TRANSLATE_NOOP("InstrumentsXML", "10 Hole G Diatonic Harmonica"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Harm.", "10 Hole G Diatonic Harmonica"),
QT_TRANSLATE_NOOP("InstrumentsXML", "10 Hole Low D Diatonic Harmonica"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Harm.", "10 Hole Low D Diatonic Harmonica"),
QT_TRANSLATE_NOOP("InstrumentsXML", "20 Hole Chordet Harmonica"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Harm.", "20 Hole Chordet Harmonica"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Harmonica"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bs. Harm.", "Bass Harmonica"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Hohner Harmonica"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bs. Harm.", "Bass Hohner Harmonica"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Huang Harmonica"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bs. Harm.", "Bass Huang Harmonica"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Accordion"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Acc.", "Accordion"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bandoneon"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Ban.", "Bandoneon"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Concertina"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Conc.", "Concertina"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Melodica"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Mel.", "Melodica"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sheng"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "She.", "Sheng"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Sheng"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "S She.", "Soprano Sheng"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Sheng"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A She.", "Alto Sheng"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Sheng"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "T She.", "Tenor Sheng"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Sheng"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B She.", "Bass Sheng"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Brass"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Brass"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Br.", "Brass"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Horn in F"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "F Hn.", "Horn in F"),
QT_TRANSLATE_NOOP("InstrumentsXML", "High C Horn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "H. C Hn.", "High C Horn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Horn in B♭"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B♭ Hn.", "Horn in B♭"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Horn in A"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A Hn.", "Horn in A"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Horn in A♭"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A♭ Hn.", "Horn in A♭"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Horn in G"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "G Hn.", "Horn in G"),
QT_TRANSLATE_NOOP("InstrumentsXML", "E Horn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "E Hn.", "E Horn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Horn in E♭"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "E♭ Hn.", "Horn in E♭"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Horn in D"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Hn.", "Horn in D"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Horn in C"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "C Hn.", "Horn in C"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Vienna Horn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "V. Hn.", "Vienna Horn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Horn in B♭ basso"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B♭ ba Hn.", "Horn in B♭ basso"),
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Cornet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "E♭ Cnt.", "E♭ Cornet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "C Cornet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "C Cnt.", "C Cornet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Cornet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B♭ Cnt.", "B♭ Cornet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "A Cornet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A Cnt.", "A Cornet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Saxhorn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Saxhorn", "Saxhorn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "F Alto Horn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "F A. Hn.", "F Alto Horn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Alto Horn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "E♭ A. Hn.", "E♭ Alto Horn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baritone Horn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bar. Hn.", "Baritone Horn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baritone Horn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bar. Hn.", "Baritone Horn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baritone Horn (Treble Clef)"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Posthorn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Psthn.", "Posthorn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alphorn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "AlpHn.", "Alphorn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Trumpet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Tpt.", "Trumpet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Piccolo Trumpet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "P. Tpt.", "Piccolo Trumpet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Piccolo Trumpet in B♭"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "P. Tpt. B♭", "Piccolo Trumpet in B♭"),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Piccolo Trumpet in A"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "P. Tpt. A", "Piccolo Trumpet in A"),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "F Trumpet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "F Tpt.", "F Trumpet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "E Trumpet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "E Tpt.", "E Trumpet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Trumpet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "E♭ Tpt.", "E♭ Trumpet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "D Trumpet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "D Tpt.", "D Trumpet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "C Trumpet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "C Tpt.", "C Trumpet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Trumpet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B♭ Tpt.", "B♭ Trumpet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "A Trumpet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A Tpt.", "A Trumpet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Pocket Trumpet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Pkt. Tpt.", "Pocket Trumpet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Slide Trumpet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Sl.Tpt.", "Slide Trumpet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Trumpet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "T. Tpt.", "Tenor Trumpet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Trumpet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B. Tpt.", "Bass Trumpet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Bass Trumpet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "E♭ B. Tpt.", "E♭ Bass Trumpet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Trumpet in C"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B. Tpt. C", "Bass Trumpet in C"),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Bass Trumpet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B♭ B. Tpt.", "B♭ Bass Trumpet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "mute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baroque Trumpet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bq. Tpt.", "Baroque Trumpet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baroque Trumpet in F"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bq. Tpt. F", "Baroque Trumpet in F"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baroque Trumpet in E♭"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bq. Tpt. E♭", "Baroque Trumpet in E♭"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baroque Trumpet in D"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bq. Tpt. D", "Baroque Trumpet in D"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baroque Trumpet in C"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bq. Tpt. C", "Baroque Trumpet in C"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baroque Trumpet in B♭"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bq. Tpt. B♭", "Baroque Trumpet in B♭"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Rag Dung"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Rg. Dng.", "Rag Dung"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bugle"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bu.", "Bugle"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Bugle"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Sop.", "Soprano Bugle"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Bugle"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Alto", "Alto Bugle"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baritone Bugle"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bari.", "Baritone Bugle"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Flugelhorn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Flghn.", "Flugelhorn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Fiscorn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Fsc.", "Fiscorn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Kuhlohorn"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Klhn.", "Kuhlohorn"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Euphonium Bugle"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Euph.", "Euphonium Bugle"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Mellophone Bugle"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Mello", "Mellophone Bugle"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabass Bugle"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Contra", "Contrabass Bugle"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Mellophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Mello", "Mellophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Ophicleide"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Oph.", "Ophicleide"),
QT_TRANSLATE_NOOP("InstrumentsXML", "F Alto Ophicleide"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "F A. Oph.", "F Alto Ophicleide"),
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Alto Ophicleide"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "E♭ A. Oph.", "E♭ Alto Ophicleide"),
QT_TRANSLATE_NOOP("InstrumentsXML", "C Bass Ophicleide"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "C B. Oph.", "C Bass Ophicleide"),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Bass Ophicleide"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B♭ B. Oph.", "B♭ Bass Ophicleide"),
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Contrabass Ophicleide"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "E♭ Cb. Oph.", "E♭ Contrabass Ophicleide"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Cornettino"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Co.", "Cornettino"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Cornett"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Co.", "Cornett"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Cornett"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "S. Co.", "Soprano Cornett"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Cornett"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A. Co.", "Alto Cornett"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Cornett"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "T. Co.", "Tenor Cornett"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Serpent"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Spt.", "Serpent"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Sackbut"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A. Sack.", "Alto Sackbut"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Sackbut"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "T. Sack.", "Tenor Sackbut"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Sackbut"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B. Sack.", "Bass Sackbut"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Trombone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Tbn.", "Trombone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Trombone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Tbn.", "Trombone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Trombone (Treble Clef)"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Trombone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "S. Tbn.", "Soprano Trombone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Trombone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A. Tbn.", "Alto Trombone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Trombone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "T. Tbn.", "Tenor Trombone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Trombone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B. Tbn.", "Bass Trombone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabass Trombone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Cb. Tbn.", "Contrabass Trombone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Cimbasso"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Cim.", "Cimbasso"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Euphonium"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Euph.", "Euphonium"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Euphonium"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Euph.", "Euphonium"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Euphonium (Treble Clef)"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tuba"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Tba.", "Tuba"),
QT_TRANSLATE_NOOP("InstrumentsXML", "F Tuba"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "F Tu.", "F Tuba"),
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Tuba"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "E♭ Tu.", "E♭ Tuba"),
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Tuba"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "E♭ Tu.", "E♭ Tuba"),
QT_TRANSLATE_NOOP("InstrumentsXML", "E♭ Tuba (Treble Clef)"),
QT_TRANSLATE_NOOP("InstrumentsXML", "C Tuba"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "C Tu.", "C Tuba"),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Tuba"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B♭ Tu.", "B♭ Tuba"),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Tuba"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B♭ Tu.", "B♭ Tuba"),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Tuba (Treble Clef)"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Tuba in F"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Ba. Tu. F", "Bass Tuba in F"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Tuba in E♭"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Ba. Tu. E♭", "Bass Tuba in E♭"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sub-Contrabass Tuba"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "SCB. Tu.", "Sub-Contrabass Tuba"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Helicon"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Helicon", "Helicon"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sousaphone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Sphn.", "Sousaphone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Sousaphone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B♭ Sphn.", "B♭ Sousaphone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Wagner Tuba"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Wag. Tu.", "Wagner Tuba"),
QT_TRANSLATE_NOOP("InstrumentsXML", "B♭ Wagner Tuba"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B♭ Wag. Tu.", "B♭ Wagner Tuba"),
QT_TRANSLATE_NOOP("InstrumentsXML", "F Wagner Tuba"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "F Wag. Tu.", "F Wagner Tuba"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Conch"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Cnch.", "Conch"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Didgeridoo"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Doo.", "Didgeridoo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Horagai"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Hor.", "Horagai"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Shofar"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Sho.", "Shofar"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Vuvuzela"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Vuv.", "Vuvuzela"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Percussion - Pitched"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Timpani"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Timp.", "Timpani"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Roto-Toms"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Roto", "Roto-Toms"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Glockenspiel"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Glock.", "Glockenspiel"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Orff Soprano Glockenspiel"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "O. S. Glk.", "Orff Soprano Glockenspiel"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Orff Alto Glockenspiel"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "O. A. Glk.", "Orff Alto Glockenspiel"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Crotales"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Crot.", "Crotales"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tubaphone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Tph.", "Tubaphone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Almglocken"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Almg.", "Almglocken"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Vibraphone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Vib.", "Vibraphone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Metallophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Met.", "Metallophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Orff Soprano Metallophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "O. S. Met.", "Orff Soprano Metallophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Orff Alto Metallophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "O. A. Met.", "Orff Alto Metallophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Orff Bass Metallophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "O. B. Met.", "Orff Bass Metallophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Chimes"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Cme.", "Chimes"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Steel Drums"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "St. Dr.", "Steel Drums"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Steel Drums"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "S. St. Dr.", "Soprano Steel Drums"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Steel Drums"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A. St. Dr.", "Alto Steel Drums"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Guitar Steel Drums"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Gtr. St. Dr.", "Guitar Steel Drums"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Steel Drums"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "T. St. Dr.", "Tenor Steel Drums"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Cello Steel Drums"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Ce. St. Dr.", "Cello Steel Drums"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Steel Drums"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B. St. Dr.", "Bass Steel Drums"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Hand Bells"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Ha. Be.", "Hand Bells"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tuned Gongs"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Td. Gon.", "Tuned Gongs"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Flexatone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Flt.", "Flexatone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Musical Saw"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Mu. Sw.", "Musical Saw"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Musical Glasses"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Mu. Gla.", "Musical Glasses"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Glass Harmonica"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Gla. Har.", "Glass Harmonica"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Xylophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Xyl.", "Xylophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Orff Soprano Xylophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "O. S. Xyl.", "Orff Soprano Xylophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Orff Alto Xylophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "O. A. Xyl.", "Orff Alto Xylophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Orff Bass Xylophone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "O. B. Xyl.", "Orff Bass Xylophone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Xylomarimba"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "XMrm.", "Xylomarimba"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Marimba"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Mrm.", "Marimba"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Marimba (Grand Staff)"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Marimba"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Mrm.", "Marimba"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Marimba (Single Staff)"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Marimba"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B. Mrm.", "Bass Marimba"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabass Marimba"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Cb. Mrm.", "Contrabass Marimba"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Dulcimer"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Dlc.", "Dulcimer"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tuned Klaxon Horns"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Tn. Klx. Hns.", "Tuned Klaxon Horns"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Kalimba"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Kal.", "Kalimba"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Treble Kalimba"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Tr. Kal.", "Treble Kalimba"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Kalimba"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A. Kal.", "Alto Kalimba"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Percussion - Unpitched"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Drumset"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "D. Set", "Drumset"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Concert Snare Drum"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Con. Sn.", "Concert Snare Drum"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Concert Bass Drum"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Con. BD ", "Concert Bass Drum"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Piccolo Snare"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Picc. Sn.", "Piccolo Snare"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Field Drum"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Field Dr.", "Field Drum"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Concert Toms"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "C. Toms", "Concert Toms"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Chinese Tom-Toms"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Ch. Toms", "Chinese Tom-Toms"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bongos"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bon.", "Bongos"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Congas"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Con.", "Congas"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Timbales"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Timb.", "Timbales"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Frame Drum"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Fr. Dr.", "Frame Drum"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tablas"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Tbs.", "Tablas"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Cuica"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Cu.", "Cuica"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Finger Cymbals"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Fi. Cym.", "Finger Cymbals"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Hi-hat"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Hi-hat", "Hi-hat"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tam-Tam"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Tam", "Tam-Tam"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bells"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Be.", "Bells"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sleigh Bells"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Sle. Be.", "Sleigh Bells"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bell Plate"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Be. Pla.", "Bell Plate"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bowl Gongs"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bw. Gon.", "Bowl Gongs"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tubo"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Tu.", "Tubo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Metal Castanets"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Met. Cst.", "Metal Castanets"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Automobile Brake Drums"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Aut. Brk. Dr.", "Automobile Brake Drums"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Iron Pipes"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Ir. Pi.", "Iron Pipes"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Chains"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Chn.", "Chains"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Anvil"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Anv.", "Anvil"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Wood Blocks"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Wd. Bl.", "Wood Blocks"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Temple Blocks"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Tmp. Bl.", "Temple Blocks"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Triangle"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Trgl.", "Triangle"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Cymbal"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Cym.", "Cymbal"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Ride Cymbal"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "R. Cym.", "Ride Cymbal"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Chinese Cymbal"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Ch. Cym.", "Chinese Cymbal"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Crash Cymbal"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Cr. Cym.", "Crash Cymbal"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Splash Cymbal"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Sp. Cym.", "Splash Cymbal"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Cowbell"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Cwb.", "Cowbell"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Claves"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Clv.", "Claves"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Castanets"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Cst.", "Castanets"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Güiro"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Gro.", "Güiro"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Maracas"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Mrcs.", "Maracas"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Cabasa"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Cabs.", "Cabasa"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Quijada"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Qui.", "Quijada"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Vibraslap"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Vibslp.", "Vibraslap"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Slit Drum"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Slt. Dr.", "Slit Drum"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Whip"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Wh.", "Whip"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Ratchet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Rat.", "Ratchet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Thundersheet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Thu.", "Thundersheet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sandpaper Blocks"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Sa. Bl.", "Sandpaper Blocks"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Wooden Wind Chimes"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Wd. Wn. Ch.", "Wooden Wind Chimes"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bamboo Wind Chimes"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bam. Wn. Ch.", "Bamboo Wind Chimes"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Metal Wind Chimes"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Met. Wn Ch.", "Metal Wind Chimes"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Glass Wind Chimes"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Gl. Wn Ch.", "Glass Wind Chimes"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Shell Wind Chimes"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Sh. Wn Ch.", "Shell Wind Chimes"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Stones"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Sto.", "Stones"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tambourine"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Tamb.", "Tambourine"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Percussion"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Perc.", "Percussion"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Percussion - Marching"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Snare Drum"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "S.D.", "Snare Drum"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Drums"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "T.D.", "Tenor Drums"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Drums"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B.D.", "Bass Drums"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Cymbals"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Cym.", "Cymbals"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Percussion - Body"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Finger Snap"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Fi. Sna.", "Finger Snap"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Hand Clap"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Hd. Clp.", "Hand Clap"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Slap"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Sla.", "Slap"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Stamp"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Sta.", "Stamp"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Vocals"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Voice"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Vo.", "Voice"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Boy Soprano"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B. S.", "Boy Soprano"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "S.", "Soprano"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Mezzo-soprano"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Mzs.", "Mezzo-soprano"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A.", "Alto"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contralto"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Contr.", "Contralto"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Countertenor"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Ct.", "Countertenor"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "T.", "Tenor"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baritone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bar.", "Baritone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B.", "Bass"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Women"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "W.", "Women"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Men"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "M.", "Men"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Kazoo"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Kaz.", "Kazoo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Keyboards"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Piano"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Pno.", "Piano"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Grand Piano"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Pno.", "Grand Piano"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Upright Piano"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Pno.", "Upright Piano"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Honky Tonk Piano"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Hnk. Pno.", "Honky Tonk Piano"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Toy Piano"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Toy Pno.", "Toy Piano"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Clavichord"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Cch.", "Clavichord"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Harpsichord"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Hch.", "Harpsichord"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Virginal"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Vir.", "Virginal"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Celesta"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Cel.", "Celesta"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Electric Piano"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "El. Pno.", "Electric Piano"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Clavinet"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Clav.", "Clavinet"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Organ"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Org.", "Organ"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Percussive Organ"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Perc. Org.", "Percussive Organ"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Hammond Organ"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Hm. Org.", "Hammond Organ"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Rotary Organ"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Rot. Org.", "Rotary Organ"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Pipe Organ"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Org.", "Pipe Organ"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Pipe Organ"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Harmonium"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Harm.", "Harmonium"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Reed Organ"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Rd. Org.", "Reed Organ"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Electronic"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Effect Synthesizer"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Synth.", "Effect Synthesizer"),
QT_TRANSLATE_NOOP("InstrumentsXML", "rain"),
QT_TRANSLATE_NOOP("InstrumentsXML", "soundtrack"),
QT_TRANSLATE_NOOP("InstrumentsXML", "crystal"),
QT_TRANSLATE_NOOP("InstrumentsXML", "atmosphere"),
QT_TRANSLATE_NOOP("InstrumentsXML", "brightness"),
QT_TRANSLATE_NOOP("InstrumentsXML", "goblins"),
QT_TRANSLATE_NOOP("InstrumentsXML", "echoes"),
QT_TRANSLATE_NOOP("InstrumentsXML", "scifi"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Atmosphere Synthesizer"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Synth.", "Atmosphere Synthesizer"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Brightness Synthesizer"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Synth.", "Brightness Synthesizer"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Crystal Synthesizer"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Synth.", "Crystal Synthesizer"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Echoes Synthesizer"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Synth.", "Echoes Synthesizer"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Goblins Synthesizer"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Synth.", "Goblins Synthesizer"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Rain Synthesizer"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Synth.", "Rain Synthesizer"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sci-fi Synthesizer"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Synth.", "Sci-fi Synthesizer"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soundtrack Synthesizer"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Synth.", "Soundtrack Synthesizer"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Pad Synthesizer"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Synth.", "Pad Synthesizer"),
QT_TRANSLATE_NOOP("InstrumentsXML", "new age"),
QT_TRANSLATE_NOOP("InstrumentsXML", "warm"),
QT_TRANSLATE_NOOP("InstrumentsXML", "polysynth"),
QT_TRANSLATE_NOOP("InstrumentsXML", "choir"),
QT_TRANSLATE_NOOP("InstrumentsXML", "bowed"),
QT_TRANSLATE_NOOP("InstrumentsXML", "metallic"),
QT_TRANSLATE_NOOP("InstrumentsXML", "halo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "sweep"),
QT_TRANSLATE_NOOP("InstrumentsXML", "New Age Synthesizer"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Synth.", "New Age Synthesizer"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Warm Synthesizer"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Synth.", "Warm Synthesizer"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Poly Synthesizer"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Synth.", "Poly Synthesizer"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Choir Synthesizer"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Synth.", "Choir Synthesizer"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bowed Synthesizer"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Synth.", "Bowed Synthesizer"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Metallic Synthesizer"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Synth.", "Metallic Synthesizer"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Halo Synthesizer"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Synth.", "Halo Synthesizer"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sweep Synthesizer"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Synth.", "Sweep Synthesizer"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Saw Synthesizer"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Synth.", "Saw Synthesizer"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sine Synthesizer"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Synth.", "Sine Synthesizer"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Square Synthesizer"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Synth.", "Square Synthesizer"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Ondes Martenot"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "O.M.", "Ondes Martenot"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Mallet Synthesizer"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Mal. Syn.", "Mallet Synthesizer"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Synthesizer"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Synth.", "Bass Synthesizer"),
QT_TRANSLATE_NOOP("InstrumentsXML", "synth-bass-1"),
QT_TRANSLATE_NOOP("InstrumentsXML", "synth-bass-2"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Brass Synthesizer"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Synth.", "Brass Synthesizer"),
QT_TRANSLATE_NOOP("InstrumentsXML", "synth-brass-1"),
QT_TRANSLATE_NOOP("InstrumentsXML", "synth-brass-2"),
QT_TRANSLATE_NOOP("InstrumentsXML", "String Synthesizer"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Synth.", "String Synthesizer"),
QT_TRANSLATE_NOOP("InstrumentsXML", "synth-string-1"),
QT_TRANSLATE_NOOP("InstrumentsXML", "synth-string-2"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Theremin"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Thmn.", "Theremin"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Percussion Synthesizer"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Perc. Syn.", "Percussion Synthesizer"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Strings - Plucked"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Banjo"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bj.", "Banjo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Banjo [Tablature]"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Banjo"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "T. Bj.", "Tenor Banjo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Irish Tenor Banjo"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "ITB", "Irish Tenor Banjo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Irish Tenor Banjo [Tablature]"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Balalaika"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bal.", "Balalaika"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Balalaika"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Piccolo Balalaika"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Pic. Bal.", "Piccolo Balalaika"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Piccolo Balalaika"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Prima Balalaika"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Pr. Bal.", "Prima Balalaika"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Prima Balalaika"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Secunda Balalaika"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Sec. Bal.", "Secunda Balalaika"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Secunda Balalaika"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Balalaika"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Al. Bal.", "Alto Balalaika"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Balalaika"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Balalaika"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B. Bal.", "Bass Balalaika"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Balalaika"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabass Balalaika"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "CB. Bal.", "Contrabass Balalaika"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabass Balalaika"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bouzouki"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bou.", "Bouzouki"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bouzouki (3-course)"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bouzouki"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bou.", "Bouzouki"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bouzouki (4-course)"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Soprano Guitar"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "S. Guit.", "Soprano Guitar"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Guitar"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A. Guit.", "Alto Guitar"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Classical Guitar"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Guit.", "Classical Guitar"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Guitar"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Guit.", "Guitar"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Guitar (Treble Clef)"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Classical Guitar [Tablature]"),
QT_TRANSLATE_NOOP("InstrumentsXML", "7-string Guitar"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Guit.", "7-string Guitar"),
QT_TRANSLATE_NOOP("InstrumentsXML", "7-string Guitar [Tablature]"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Cavaquinho"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Cava.", "Cavaquinho"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Cavaquinho [Tablature]"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baritone Guitar"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bar. Guit.", "Baritone Guitar"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contra Guitar"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "C. Guit.", "Contra Guitar"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Acoustic Guitar"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Guit.", "Acoustic Guitar"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Guitar"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Guit.", "Guitar"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Acoustic Guitar (Treble Clef)"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Acoustic Guitar [Tablature]"),
QT_TRANSLATE_NOOP("InstrumentsXML", "11-string Alto Guitar"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "11-str. A. Guit.", "11-string Alto Guitar"),
QT_TRANSLATE_NOOP("InstrumentsXML", "12-string Guitar"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "12-str. Guit.", "12-string Guitar"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Pedal Steel Guitar"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Ped. St. Guit.", "Pedal Steel Guitar"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Electric Guitar"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "El. Guit.", "Electric Guitar"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Electric Guitar"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "El. Guit.", "Electric Guitar"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Electric Guitar (Treble Clef)"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Electric Guitar [Tablature]"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Harp"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Hrp.", "Harp"),
QT_TRANSLATE_NOOP("InstrumentsXML", "staccato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "flageoletti"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Koto"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Ko.", "Koto"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Oud"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "O.", "Oud"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Lt.", "Lute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute [Tablature]"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Lt.", "Lute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute 5-course"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Lt.", "Lute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute 6-course"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Lt.", "Lute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute 7-course"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Lt.", "Lute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute 8-course"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Lt.", "Lute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute 9-course"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Lt.", "Lute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute 10-course"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Lt.", "Lute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Lute 13-course"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Archlute"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A. Lt.", "Archlute"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Theorbo"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Thb.", "Theorbo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Mandolin"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Mdn.", "Mandolin"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Mandolin [Tablature]"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Mandola"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Mda.", "Mandola"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Mandola"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A. Mda.", "Alto Mandola"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Mandola"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "T. Mda.", "Tenor Mandola"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Mandocello"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Mncl.", "Mandocello"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Octave Mandolin"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "OM.", "Octave Mandolin"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Shamisen"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Sh.", "Shamisen"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Sitar"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Si.", "Sitar"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Ukulele"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Uk.", "Ukulele"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Ukulele [Tablature]"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Ukulele (Low G)"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Uk.", "Ukulele (Low G)"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Ukulele"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Ten. Uk.", "Tenor Ukulele"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baritone Ukulele"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bar. Uk.", "Baritone Ukulele"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Guitar"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "B. Guit.", "Bass Guitar"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bass Guitar [Tablature]"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Acoustic Bass"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bass", "Acoustic Bass"),
QT_TRANSLATE_NOOP("InstrumentsXML", "arco"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "slap"),
QT_TRANSLATE_NOOP("InstrumentsXML", "pop"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Electric Bass"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "El. B.", "Electric Bass"),
QT_TRANSLATE_NOOP("InstrumentsXML", "slap"),
QT_TRANSLATE_NOOP("InstrumentsXML", "pop"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Electric Bass [Tablature]"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Fretless Electric Bass"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Frtl. El. B.", "Fretless Electric Bass"),
QT_TRANSLATE_NOOP("InstrumentsXML", "slap"),
QT_TRANSLATE_NOOP("InstrumentsXML", "pop"),
QT_TRANSLATE_NOOP("InstrumentsXML", "5-str. Electric Bass"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "El. B.", "5-str. Electric Bass"),
QT_TRANSLATE_NOOP("InstrumentsXML", "slap"),
QT_TRANSLATE_NOOP("InstrumentsXML", "pop"),
QT_TRANSLATE_NOOP("InstrumentsXML", "5-str. Electric Bass [Tablature]"),
QT_TRANSLATE_NOOP("InstrumentsXML", "5-str. Electric Bass"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "El. B.", "5-str. Electric Bass"),
QT_TRANSLATE_NOOP("InstrumentsXML", "5-str. Electric Bass (High C/Tenor)"),
QT_TRANSLATE_NOOP("InstrumentsXML", "slap"),
QT_TRANSLATE_NOOP("InstrumentsXML", "pop"),
QT_TRANSLATE_NOOP("InstrumentsXML", "5-str. Electric Bass (High C/Tenor) [Tablature]"),
QT_TRANSLATE_NOOP("InstrumentsXML", "6-str. Electric Bass"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "El. B.", "6-str. Electric Bass"),
QT_TRANSLATE_NOOP("InstrumentsXML", "slap"),
QT_TRANSLATE_NOOP("InstrumentsXML", "pop"),
QT_TRANSLATE_NOOP("InstrumentsXML", "6-str. Electric Bass [Tablature]"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Prim"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Pr.", "Prim"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Brač"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Br.", "Brač"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Čelo"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Č.", "Čelo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Bugarija"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bu.", "Bugarija"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Berda"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Be.", "Berda"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Strings - Bowed"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Strings"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "St.", "Strings"),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Erhu"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Eh.", "Erhu"),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Nyckelharpa"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Nyh.", "Nyckelharpa"),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Violin"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Vln.", "Violin"),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Violins"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Vlns.", "Violins"),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Viola"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Vla.", "Viola"),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Violas"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Vlas.", "Violas"),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Violoncello"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Vc.", "Violoncello"),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Violoncellos"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Vcs.", "Violoncellos"),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabass"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Cb.", "Contrabass"),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Contrabasses"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Cbs.", "Contrabasses"),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Double Bass"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Db.", "Double Bass"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Pardessus de viole"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Pds. v.", "Pardessus de viole"),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Treble Viol"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Tr. Vl.", "Treble Viol"),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Alto Viol"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "A. Vl.", "Alto Viol"),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Tenor Viol"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "T. Vl.", "Tenor Viol"),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Viola da gamba"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Vla. d. g.", "Viola da gamba"),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Viola da gamba (Tab)"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Vla. d. g.", "Viola da gamba (Tab)"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Viola da gamba (Tablature)"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Baryton"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Bary.", "Baryton"),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "Violone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "Vne.", "Violone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
QT_TRANSLATE_NOOP("InstrumentsXML", "D Violone"),
QT_TRANSLATE_NOOP3("InstrumentsXML", "D Vne.", "D Violone"),
QT_TRANSLATE_NOOP("InstrumentsXML", "pizzicato"),
QT_TRANSLATE_NOOP("InstrumentsXML", "tremolo"),
